@@ -9,7 +9,7 @@ use Validate::Tiny ':all';
 use Email::Valid;
 
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 my $settings = plugin_setting;
 
@@ -24,7 +24,7 @@ register validator => sub
 	my $rules = _load_rules($rules_file);
 
 	# Validating
-	my $validator = Validate::Tiny->new($params, $rules);
+	my $validator = Validate::Tiny->check($params, $rules);
 
 	# If you need a full Validate::Tiny object
 	if($settings->{is_full} eq 1)
@@ -118,7 +118,7 @@ Dancer::Plugin::ValidateTiny - Validate::Tiny Dancer plugin.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =head1 SYNOPSIS
 
